@@ -92,10 +92,11 @@ class Serialize:
 
             # Convert to URL of Fields
             elif field_type in ('ImageField', 'FileField'):
-                if getattr(instance, field.name, None) is None:
+                instance_value = getattr(instance, field.name, '')
+                if instance_value == '':
                     instance_dict[field.name] = None
                 else:
-                    instance_dict[field.name] = getattr(instance, field.name).url
+                    instance_dict[field.name] = instance_value.url
 
             elif field_type in ('ForeignKey', 'OneToOneField'):
 
